import enum


class Season(enum.IntEnum):
    """Use for season specific calculation. See :ref:`season_about` for more information."""

    VELOCITY_VORTEX = 1617
    RELIC_RECOVERY = 1718
    ROVER_RUCKUS = 1819
    SKYSTONE = 1920
